@@ -1,8 +1,8 @@
-#define SAMTOOLS_VERSION "1.19.2"
+#define SAMTOOLS_VERSION "1.20"
 #define SAMTOOLS_CC "clang"
 #define SAMTOOLS_CPPFLAGS "-D__USE_MINGW_ANSI_STDIO=1 -D_XOPEN_SOURCE=600"
 #define SAMTOOLS_CFLAGS "-Wall -O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong"
-#define SAMTOOLS_LDFLAGS "-pipe"
+#define SAMTOOLS_LDFLAGS ""
 #define SAMTOOLS_HTSDIR ""
 #define SAMTOOLS_LIBS "-lregex "
 #define SAMTOOLS_CURSES_LIB "-lncursesw"
